/* $Workfile: OtxDspD.h $   $Revision: 64 $    $Modtime: 4/22/05 3:44p $  */
#ifndef OTX_DSP_DEF_H
#define OTX_DSP_DEF_H
/*******************************************************************************

  @doc PublicHwApi OtxDspD

  Copyright (C) 1998-2003 Odin TeleSystems Inc., All Rights Reserved

  OTX Generic Hardware Driver API

  @module
  OtxDspD | Constants, Macros, and Types for the DSP Device Management Functions

  @contents2
  OtxDspD.h |

  @index enum struct type | OtxDspD

  @contents2
  OTX DSP Device Management Macros, Constants, and Types |

  @head3 OtxDspXXX Macro, Constant, and Type Reference |

  @index enum struct type | OtxDspD

*******************************************************************************/

#include "OtxType.h"    // OTX specific type definitions

#include "OtxErr.h"

#ifdef __cplusplus
extern "C" {
#endif


/*******************************************************************************
  @enum Standard Program Modules (SPM)

  @comm DSP program modules are loaded in the DSPs by calling <f OtxDspRunSpm>. 
   The DSP program modules listed below are supported by all of the following 
   boards: 
    <nl> Thor-2-PCMCIA, 
    <nl> Thor-2-PCMCIA-Plus, 
    <nl> Thor-2-PCMCIA-EX, 
    <nl> Thor-2-PCMCIA-PRO, 
    <nl> Thor-2-PCMCIA-CST, 
    <nl> Vidar-5x4-ASM, 
    <nl> Vidar-5x4-ASM-EX, 
    <nl> Vidar-5x4-ASM-PRO, 
    <nl> Vidar-5x4-ASM-CST, 
    <nl> Vidar-5x16-PCI.

  @comm OtxSpm1 supports the following logical devices:
    <nl> OTX_LDEVICE_HDLC_RECEIVER,  
    <nl> OTX_LDEVICE_HDLC_SENDER,    
    <nl> OTX_LDEVICE_DATA_RAW_RECEIVER,  
    <nl> OTX_LDEVICE_DATA_RAW_SENDER,    
    <nl> OTX_LDEVICE_TONE_DTMF_DETECTOR,
    <nl> OTX_LDEVICE_TONE_DTMF_DIALER,
    <nl> OTX_LDEVICE_TONE_EFFECTS_GENERATOR,
    <nl> OTX_LDEVICE_DATA_CONVERTER,
    <nl> OTX_LDEVICE_TONE_CONST_VAL_GENERATOR,
    <nl> OTX_LDEVICE_TONE_VAL_SAMPLER,
    <nl> OTX_LDEVICE_TONE_SINEWAVE_GENERATOR,
    <nl> OTX_LDEVICE_TONE_SILENCE_DETECTOR,
    <nl> OTX_LDEVICE_TONE_FSK_DETECTOR

   The OtxSpm1 is memory limited to 8 devices for the HDLC Sender, 
   HDLC Receiver, Raw Data Sender, Raw Data Receiver. 

   The HDLC Sender and HDLC Receiver devices consume a fair amount of mips,
   thus the mips limitation might be reached before the memory limitation is
   reached.

   The number of other devices (other than HDLC and Raw Data) that the OtxSpm1
   supports varies depending on which DSP is populated on the board. The 
   following list specifies the number of other devices that the OtxSpm1 supports:
    <nl> Thor-2-PCMCIA       - 16 devices, 
    <nl> Thor-2-PCMCIA-Plus  - 16 devices, 
    <nl> Thor-2-PCMCIA-EX    - 20 devices, 
    <nl> Thor-2-PCMCIA-PRO   - 32 devices, 
    <nl> Thor-2-PCMCIA-CST   - 16 devices, 
    <nl> Vidar-5x4-ASM       - 16 devices, 
    <nl> Vidar-5x4-ASM-EX    - 20 devices, 
    <nl> Vidar-5x4-ASM-PRO   - 32 devices, 
    <nl> Vidar-5x4-ASM-CST   - 16 devices, 
    <nl> Vidar-5x16-PCI      - 16 devices.
    
   OtxSpm1 supports pipes of capacity 64kbps and 128kbps.

  @comm OtxSpm2 supports the following logical devices:
    <nl> OTX_LDEVICE_HDLC_SENDER
    <nl> OTX_LDEVICE_HDLC_RECEIVER
    <nl> OTX_LDEVICE_DATA_RAW_SENDER
    <nl> OTX_LDEVICE_DATA_RAW_RECEIVER
    <nl> OTX_LDEVICE_TONE_FSK_DETECTOR
    <nl> OTX_LDEVICE_TONE_DTMF_DETECTOR
    <nl> OTX_LDEVICE_TONE_MF_DETECTOR
    <nl> OTX_LDEVICE_TONE_DUAL_DETECTOR
    <nl> OTX_LDEVICE_TONE_SINGLE_DETECTOR
    <nl> OTX_LDEVICE_TONE_DTMF_GENERATOR
    <nl> OTX_LDEVICE_TONE_DTMF_DIALER
    <nl> OTX_LDEVICE_TONE_MF_DIALER
    <nl> OTX_LDEVICE_TONE_EFFECTS_GENERATOR
    <nl> OTX_LDEVICE_DATA_CONVERTER
    <nl> OTX_LDEVICE_TONE_CONST_VAL_GENERATOR
    <nl> OTX_LDEVICE_TONE_VAL_SAMPLER
    <nl> OTX_LDEVICE_TONE_SINEWAVE_GENERATOR
    <nl> OTX_LDEVICE_TONE_SILENCE_DETECTOR

   OtxSpm2 supports pipes of capacity 64kbps and 128kbps.

   The OtxSpm2 is memory limited to 8 devices for the HDLC Sender, 
   HDLC Receiver, Raw Data Sender, Raw Data Receiver. 

   The HDLC Sender and HDLC Receiver devices consume a fair amount of mips,
   thus the mips limitation might be reached before the memory limitation is
   reached.

   The number of other devices (other than HDLC and Raw Data) that the OtxSpm2
   supports varies depending on which DSP is populated on the board. The 
   following list specifies the number of other devices that the OtxSpm2 supports:
    <nl> Thor-2-PCMCIA       - 8  devices, 
    <nl> Thor-2-PCMCIA-Plus  - 8  devices, 
    <nl> Thor-2-PCMCIA-EX    - 20 devices, 
    <nl> Thor-2-PCMCIA-PRO   - 32 devices, 
    <nl> Thor-2-PCMCIA-CST   - 8  devices, 
    <nl> Vidar-5x4-ASM       - 8  devices, 
    <nl> Vidar-5x4-ASM-EX    - 20 devices, 
    <nl> Vidar-5x4-ASM-PRO   - 32 devices, 
    <nl> Vidar-5x4-ASM-CST   - 8  devices, 
    <nl> Vidar-5x16-PCI      - 8  devices.

  @comm OtxSpm2Ex supports the same logical devices as OtxSpm2. The added feature
  of OtxSpm2Ex is lower latency HDLC decoding/encoding (1ms in OtxSpm2Ex vs 12.75ms 
  in OtxSpm2). OtxSpm2Ex also supports 16kpbs and 32kpbs subrates for HDLC devices
  (whereas OtxSpm2 only supports 64kpbs HDLC devices). OtxSpm2Ex and OtxSpm2 both have 
  12.75 ms bufferering for tone devices.

  @comm OtxHdlc supports the following logical devices:
    <nl> OTX_LDEVICE_HDLC_RECEIVER 
    <nl> OTX_LDEVICE_HDLC_SENDER   
    <nl> OTX_LDEVICE_DATA_RAW_SENDER
    <nl> OTX_LDEVICE_DATA_RAW_RECEIVER
    <nl> OTX_LDEVICE_DATA_CONVERTER
    
   OtxHdlc supports pipes of capacity 8kbps, 16kbps, 32kbps and n*64kbps.

   The OtxHdlc is memory limited to 32 devices for all of the devices listed above. 
   However, the HDLC Sender and HDLC Receiver devices consume a fair amount of mips,
   thus the mips limitation will be reached before the memory limitation is
   reached. The mips limitation varies depending on which DSP is populated on the 
   board. The following list specifies the approximate number of other devices that
   can be safely be used before the mips limiation is reached:
    <nl> Thor-2-PCMCIA       - 8  devices, 
    <nl> Thor-2-PCMCIA-Plus  - 12 devices, 
    <nl> Thor-2-PCMCIA-EX    - 16 devices, 
    <nl> Thor-2-PCMCIA-PRO   - 16 devices, 
    <nl> Thor-2-PCMCIA-CST   - 12 devices, 
    <nl> Vidar-55x4-ASM      - 32 devices, 
    <nl> Vidar-5x4-ASM       - 8  devices, 
    <nl> Vidar-5x4-ASM-EX    - 16 devices, 
    <nl> Vidar-5x4-ASM-PRO   - 16 devices, 
    <nl> Vidar-5x4-ASM-CST   - 12 devices, 
    <nl> Vidar-5x16-PCI      - 8  devices.
 
  @comm OtxHdlcEx supports the following logical devices:
    <nl> OTX_LDEVICE_HDLC_RECEIVER 
    <nl> OTX_LDEVICE_HDLC_SENDER   
    
   OtxHdlcEx supports pipes of capacity n*64kbps.

   The OtxHdlcEx can be run on 5416 and 5510 DSPs and it can handle HDLC pipes
   as wide as 31 timeslots. OtxHdlcEx is memory limited (not MIPS limited). The 
   following limitations apply:

    <nl> Thor-2-PCMCIA-PRO   - 16 devices, 
    <nl> Vidar-55x4-ASM      - 32 devices, 
 

  @comm The OtxDtTx and OtxSpm3 are only supported by the 
    <nl> Thor-2-PCMCIA, 
    <nl> Thor-2-PCMCIA-Plus,
    <nl> Vidar-5x4-ASM,
    <nl> Vidar-5x16-ASM
     
   For other boards, please use the OtxSpm2 program. The OtxDtTx and OtxSpm3 is 
   just a subset of the OtxSpm2 program, and the only reason for their existance
   is the memory constaint (32kword) on the 548/549 DSPs.
  
   The OtxDtTx supports the following logical devices:
    <nl> OTX_LDEVICE_TONE_DTMF_DIALER  
    <nl> OTX_LDEVICE_TONE_CONST_VAL_GENERATOR
    <nl> OTX_LDEVICE_TONE_VAL_SAMPLER

   OtxDtTx supports pipes of capacity 64kbps.

   OtxSpm3 supports the following logical devices:
    <nl> OTX_LDEVICE_HDLC_RECEIVER  
    <nl> OTX_LDEVICE_HDLC_SENDER    
    <nl> OTX_LDEVICE_DATA_RAW_RECEIVER 
    <nl> OTX_LDEVICE_DATA_RAW_SENDER    
    <nl> OTX_LDEVICE_TONE_DTMF_DETECTOR
    <nl> OTX_LDEVICE_TONE_DTMF_DIALER
    <nl> OTX_LDEVICE_TONE_CONST_VAL_GENERATOR
    <nl> OTX_LDEVICE_TONE_VAL_SAMPLER
    
   The OtxSpm3 is memory limited to 2 devices for the HDLC Sender, 
   HDLC Receiver, Raw Data Sender, Raw Data Receiver. 

   The OtxSpm3 is memory limited to 30 devices for other supported 
   devices listed above.

  @comm The OtxCst2 are only supported by the 
    <nl> Arni-6x6-PCI-Plus (and other Arni-6x6 variants), 
    <nl> Thor-2-PCMCIA-CST,
    <nl> Vidar-5x4-ASM-CST,

   OtxCst2 supports pipes of capacity 64kbps (128kpbs pipe support planned).

   OtxCst2 supports the following logical devices:
    <nl> OTX_LDEVICE_CST_DTMF_DETECTOR   
    <nl> OTX_LDEVICE_CST_DTMF_DIALER         
    <nl> OTX_LDEVICE_CST_VOICE_MIXER         
    <nl> OTX_LDEVICE_CST_CPT_DETECTOR        
    <nl> OTX_LDEVICE_CST_CPT_GENERATOR        
    <nl> OTX_LDEVICE_CST_ECHO_CANCEL
    <nl> OTX_LDEVICE_CST_COMFORT_NOISE_GENERATOR
    <nl> OTX_LDEVICE_CST_VOICE_ACTIVITY_DETECTOR
    <nl> OTX_LDEVICE_CST_CALLER_ID_DETECTOR
    <nl> OTX_LDEVICE_CST_LI_POTS             

  @comm The OtxCst3 program is only supported by the 
    <nl> Arni-6x6-PCI-Plus (and other Arni-6x6 variants), 
    <nl> Thor-2-PCMCIA-CST,
    <nl> Vidar-5x4-ASM-CST,

   OtxCst3 supports pipes of capacity 64kbps.

   OtxCst3 supports the following logical devices:
    <nl> OTX_LDEVICE_CST_DTMF_DETECTOR   
    <nl> OTX_LDEVICE_CST_DTMF_DIALER         
    <nl> OTX_LDEVICE_CST_VOICE_MIXER         
    <nl> OTX_LDEVICE_CST_CPT_DETECTOR
    <nl> OTX_LDEVICE_CST_CPT_GENERATOR        
    <nl> OTX_LDEVICE_CST_ECHO_CANCEL
    <nl> OTX_LDEVICE_CST_COMFORT_NOISE_GENERATOR
    <nl> OTX_LDEVICE_CST_VOICE_ACTIVITY_DETECTOR
    <nl> OTX_LDEVICE_CST_CALLER_ID_DETECTOR
    <nl> OTX_LDEVICE_HDLC_RECEIVER  
    <nl> OTX_LDEVICE_HDLC_SENDER    
    <nl> OTX_LDEVICE_DATA_RAW_RECEIVER 
    <nl> OTX_LDEVICE_DATA_RAW_SENDER    


*******************************************************************************/
enum OtxDspSpmE {
  OTX_DSP_SPM_OTXSPM1,         // @emem DSP Program OtxSpm1 (available for C548/C549, C54CST, C5410A, and C5416 DSPs)
  OTX_DSP_SPM_OTXSPM2,         // @emem DSP Program OtxSpm2.out (available for C548/C549, C54CST, C5410A, and C5416 DSPs)
  OTX_DSP_SPM_OTXSPM2_EXTMEM,  // @emem DSP Program OtxSpm2c549ExtMem.out(available for C548/C549 with 64kword external memory (Vidar-5x4-ASM))
  OTX_DSP_SPM_OTXSPM3,         // @emem DSP Program OtxSpm3.out (No longer supported. Use <e OtxDspSpmE.OTX_DSP_SPM_OTXSPM2> instead)
  OTX_DSP_SPM_OTXHDLC,         // @emem DSP Program OtxHdlc.out (available for C548/C549, C54CST, C5410A, C5416, and C5510 DSPs)
  OTX_DSP_SPM_OTXHDLCEX,       // @emem DSP Program OtxHdlcEx.out (available for C5416 and C5510 DSPs)
  OTX_DSP_SPM_OTXDTTX,         // @emem DSP Program OtxDtTx.out (only targeted for the C548/C549 DSPs)
  OTX_DSP_BERT,	               // @emem DSP bert program bert.out (Odin internal)
  OTX_DSP_DIAG,	               // @emem DSP Diagnostics program (Odin internal)
  OTX_DSP_DS0,	               // @emem DSP DS0 Visual program (Odin internal)
  OTX_DSP_SPM_DSPBERT,         // @emem DSP DspBert program dspbert.out (Odin internal, available for C548/C549 DSPs)
  OTX_DSP_SPM_OTXSPM2EX,       // @emem DSP Program OtxSpm2Ex.out (available for C5410A, and C5416 DSPs)
  OTX_DSP_SPM_OTXCST2,         // @emem DSP Program OtxSpmCst2.out (available for C54CST DSPs; targeted for Arni-6x6-PCI types of boards)
  OTX_DSP_SPM_OTXCST3,         // @emem DSP Program OtxSpmCst3.out (available for C54CST DSPs; targeted for Vidar-CST and PCMCIA-CST boards)
};

typedef enum OtxDspSpmE OtxDspSpmE;


/******************************************************************************
  @enum 
    DSP Device Attributes
******************************************************************************/
enum OtxDspDeviceAttributesE {
  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_CURRENT_USAGE            = OTX_ATTR_END + 0,  // @emem (OTX_ATTRIB_UINT32) Read-only. Current number of words in use of the 
                                                                                    // HPI Notification Event Buffer
  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_MAX_USAGE                = OTX_ATTR_END + 1,  // @emem (OTX_ATTRIB_UINT32) Read-only. Maximum number of words in use of the 
                                                                                    // HPI Notification Event Buffer (since the application started)
  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_LOST_EVENTS              = OTX_ATTR_END + 2,  // @emem (OTX_ATTRIB_UINT32) Read-only. Number of the lost events (due to a 
                                                                                    // full HPI Notification Event Buffer)
  OTX_ATTR_DSP_NOTIFICATION_EVENT_EXT_QUEUE_CURRENT_USAGE      = OTX_ATTR_END + 3,  // @emem (OTX_ATTRIB_UINT32) Read-only. Current number of Notification Event packets
                                                                                    // in the extended event queue (located outside of the HPI Notification Buffer)  
  OTX_ATTR_DSP_NOTIFICATION_EVENT_EXT_QUEUE_PEAK_USAGE         = OTX_ATTR_END + 4,  // @emem (OTX_ATTRIB_UINT32) Read-only. Current number of Notification Event packets
                                                                                    // in the extended event queue (located outside of the HPI Notification Buffer)  

  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_ADDR                     = OTX_ATTR_END + 5,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Start address of the HPI Notification 
                                                                                    // Event Buffer
  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_SIZE                     = OTX_ATTR_END + 6,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Size (in words) of the HPI Notification Event Buffer
  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_PROCESSING_ADDR          = OTX_ATTR_END + 7,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Address of where the host driver will 
                                                                                    // write the address of its Notification Event Buffer Read Pointer (i.e. the 
                                                                                    // address of where it will read the next Notification Event from)
  OTX_ATTR_DSP_IOCTL_CODE_ADDR                                 = OTX_ATTR_END + 8,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Start address of the DSP IO Control packet.
  OTX_ATTR_DSP_IOCTL_DATA_MAX_SIZE                             = OTX_ATTR_END + 9,  // @emem (OTX_ATTRIB_UINT32) Read/Write. Maximum data length of the DSP IO Control 
                                                                                    // packet.
  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_INCLUDE_HANDLE           = OTX_ATTR_END + 10,  // @emem (OTX_ATTRIB_BOOL) Read/Write. If OTX_TRUE the DSP code must include the 
                                                                                    // DSP Handle in the Notification Events
  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_INCLUDE_TASKREF          = OTX_ATTR_END + 11,  // @emem (OTX_ATTRIB_BOOL) Read/Write. If OTX_TRUE the DSP code must include the 
                                                                                    // TaskRef in the Notification Events
  OTX_ATTR_DSP_NOTIFICATION_EVENT_BUF_INCLUDE_TIMESTAMP        = OTX_ATTR_END + 12, // @emem (OTX_ATTRIB_BOOL) Read/Write. If OTX_TRUE the DSP code must include the 
                                                                                    // TimeStamp in the Notification Events
  OTX_ATTR_DSP_IOCTL_INCLUDE_HANDLE                            = OTX_ATTR_END + 13, // @emem (OTX_ATTRIB_BOOL) Read/Write. If OTX_TRUE the host driver will include the 
                                                                                    // DSP Handle in the DSP IO Control packet
  OTX_ATTR_DSP_IOCTL_INCLUDE_TASKREF                           = OTX_ATTR_END + 14, // @emem (OTX_ATTRIB_BOOL) Read/Write. If OTX_TRUE the host driver will include 
                                                                                    // the TaskRef in the DSP IO Control packet
  OTX_ATTR_DSP_AUTO_DISABLE                                    = OTX_ATTR_END + 15, // @emem (OTX_ATTRIB_BOOL) Read/Write. Default OTX_TRUE. If OTX_TRUE the driver 
                                                                                    // will automatically disable the device if the Notification Event buffer encounters
                                                                                    // to many serious errors. A call to <f OtxDrvReset> will reset the error counter for
                                                                                    // serious errors.
                                                              
  OTX_ATTR_DSP_FRAME_BUFFER_COUNTER                            = OTX_ATTR_END + 16, // @emem (OTX_ATTRIB_UINT32) Read only. The Frame Buffer Counter is a 16 bit value
                                                                                    // which is incremented by the DSP code every time it receives another buffer 
                                                                                    // interrupt (highway serial port). Since each DSP is clocked from the same Frame Sync
                                                                                    // clock this counter can be used to synchronize certain events (such as a synchronized 
                                                                                    // enabling of multiple devices). The counter will wrap once it reaches 0xFFFF. The size
                                                                                    // of the frame buffer (auto buffer) is set by each DSP program, but the Frame sync pulse
                                                                                    // always occurs every 125 us.
  OTX_ATTR_DSP_FRAME_COUNTER                                   = OTX_ATTR_END + 17, // @emem (OTX_ATTRIB_UINT32) Read only. The Frame Counter is a 16 bit value
                                                                                    // which is incremented by the DSP code every time it receives another buffer 
                                                                                    // interrupt (highway serial port). It is similar to the 
                                                                                    // <e OtxDspDeviceAttributesE.OTX_ATTR_DSP_FRAME_BUFFER_COUNTER> attribute except that this
                                                                                    // counter is incremented by the number of frames in each buffer. Therefore this attribute
                                                                                    // can be used to get an accurate count of how many frames that the DSP has received since
                                                                                    // the DSP was started. The time difference between each frame is 125us.
  OTX_ATTR_DSP_HIGHWAY_SPEED                                   = OTX_ATTR_END + 18, // @emem (OTX_ATTRIB_UINT32) Read only. DSP Highway speed in kbps. Valid values are
                                                                                    // 2048, 4096, and 8192. The highway speed determines how many timeslots that the DSP can
                                                                                    // work with. On a 2048 kpbs highway there are 32 timeslots. On a 4096 kbps highway there
                                                                                    // are 64 timeslots, and on an 8192 kpbs highway there are 128 timeslots.

  OTX_ATTR_DSP_HIGHWAY_BIT_FREQUENCY                           = OTX_ATTR_END + 19, // @emem (OTX_ATTRIB_UINT32) Read only. 
                                                                                    // <nl>If supported by the loaded DSP program,
                                                                                    // this attribute returns the bit frequency of the DSP highway in Hertz. 

  OTX_ATTR_DSP_END                                             = OTX_ATTR_END + 20
};

typedef enum OtxDspDeviceAttributesE OtxDspDeviceAttributesE;


/******************************************************************************
  @enum
    DSP Error Result Codes
******************************************************************************/
enum OtxDspResultCodesE {
  OTX_DSP_RES_DATA_TOO_LARGE               = OTX_RES_END +  0 ,  // @emem Data too large for the supplied buffer. Supply a larger buffer.
  OTX_DSP_RES_INVALID_CHANNEL              = OTX_RES_END +  1 ,  // @emem Invalid channel
  OTX_DSP_RES_COMM_FAILURE                 = OTX_RES_END +  2 ,  // @emem Communication failure with the DSP
  OTX_DSP_RES_NO_KERNEL_RESPONSE           = OTX_RES_END +  3 ,  // @emem No response from DSP Kernel
  OTX_DSP_RES_NO_FREE_LOGICAL_DEVICE       = OTX_RES_END +  4 ,  // @emem No free logical device

  OTX_DSP_RES_END                          = OTX_RES_END +  1
};

typedef enum OtxDspResultCodesE OtxDspResultCodesE;


/******************************************************************************
  @enum
    DSP Event Codes
******************************************************************************/
enum OtxDspEventCodesE {
  // OtxSpm1 Specific Event Codes
  OTX_DSP_EC_RX_OVERFLOW                 = 0x00, // @emem OtxSpm1 Receive overflow
  OTX_DSP_EC_INTERNAL_ERROR              = 0x01, // @emem OtxSpm1 Undefined Internal error
  OTX_DSP_EC_UNKNOWN_NOTIFY_CODE         = 0x02, // @emem OtxSpm1 Error. Unknown notify code for System Notify Event Handle.

  // Generic DSP Module Event Codes
  OTX_DSP_EC_INVALID_NOTIFY_EVENT_HANDLE = 0x03, // @emem Invalid Notify Event Handle. Could not find a matching logical device for this handle.
  OTX_DSP_EC_NOTIFY_EVENT_OVERFLOW       = 0x04, // @emem Event frequency too high. Driver cannot handle all these events. 
  OTX_DSP_EC_AUTO_DISABLED               = 0x05, // @emem Fatal error has occurred. The device is automatically disabled.
  OTX_DSP_EC_NOTIFY_EVENT_FREQ_HIGH      = 0x06, // @emem Event frequency from the DSP is seriously high. Fatal errors are imminent.
//OTX_DSP_EC_DEBUG_INFO                  = 0x07, // @emem Internal use. For driver debugging.

//*****************************
#ifdef _TURNSTONE_
//*****************************
  OTX_DSP_EC_PATTERN_SYNC                = 0x06,
  OTX_DSP_EC_PATTERN_UNKNOWN             = 0x07,
  OTX_DSP_EC_RXBUFFER_OVERFLOW           = 0x08,
  OTX_DSP_EC_BITERROR_UPDATE             = 0x09,
  OTX_DSP_EC_TEST_PATTERN_FAILURE        = 0x0A,
  OTX_DSP_EC_TEST_PATTERN_SUCCESS        = 0x0B,
  OTX_DSP_EC_DS0VISUAL_UPDATE            = 0x0C,
//******************************
#endif   //_TURNSTONE_
//******************************

  OTX_DSP_END_OF_EVENT_CODES          
};
typedef enum OtxDspEventCodesE OtxDspEventCodesE;


/******************************************************************************
  @enum
    User Application Error Result Codes
******************************************************************************/
enum OtxUserApplicationResultCodesE {
  OTX_USER_APPLICATION_RES_DATA_TRUNCATED  = OTX_RES_END +  0 ,  // @emem DSP User application has transferred a data buffer that is too large. Data is truncated.        
  OTX_USER_APPLICATION_RES_END             = OTX_RES_END +  1
};

typedef enum OtxUserApplicationResultCodesE OtxUserApplicationResultCodesE;


/******************************************************************************
  @enum
    DSP User Application Logical Device Event Codes
******************************************************************************/
enum OtxUserApplicationEventCodesE {
  OTX_USER_APPLICATION_EC_READ_DATA                = 0x00, // @emem DSP User Application Notify Data is available
  OTX_USER_APPLICATION_EC_READ_DATA_OVERRUN        = 0x01, // @emem DSP User Application Notify Data Fifo Overrun. User application is too slow extracting data from the driver

  OTX_USER_APPLICATION_END_OF_EVENT_CODES          
};
typedef enum OtxUserApplicationEventCodesE OtxUserApplicationEventCodesE;



#ifdef __cplusplus
}  // extern "C"
#endif

/*******************************************************************************

  Copyright (C) Odin TeleSystems Inc., 1998-2003

  All rights reserved. No part of this computer program may be reproduced,
  stored in any retrieval system, or transmitted, in any form or by any
  means, electronic, mechanical, photocopying, recording, or otherwise,
  without the prior written permission of Odin TeleSystems Inc., or without
  a permission stipulated in the agreement/contract under which this computer
  program was supplied.

*******************************************************************************/
#endif    // OTX_DSP_DEF_H
